@@ -75,6 +75,8 @@ ENVIRONMENT::ENVIRONMENT (GLOBALDATA *global):_global(global),done(NULL),fp(NULL
   global_tank_index = 0;
 
   initialise ();
+  waiting_sky_lock = init_lock(waiting_sky_lock);
+  waiting_terrain_lock = init_lock(waiting_terrain_lock);
 }
 
 
@@ -87,6 +89,9 @@ ENVIRONMENT::~ENVIRONMENT()
 {
   int count;
 
+  destroy_lock(waiting_sky_lock);
+  destroy_lock(waiting_terrain_lock);
+
   if (db)      destroy_bitmap(db);      db      = NULL;
   if (sky)     destroy_bitmap(sky);     sky     = NULL;
   if (waiting_sky) destroy_bitmap(sky); waiting_sky = NULL;
@@ -112,9 +117,133 @@ ENVIRONMENT::~ENVIRONMENT()
      free(bitmap_filenames);
   }
 }
-
-
-
+void ENVIRONMENT::destroy_lock(pthread_mutex_t* lock) {
+  #ifdef THREADS
+  if (lock)
+  {
+    int result = pthread_mutex_destroy(lock);
+    switch (result)
+    {
+      case 0:
+        //Successfully destroyed
+        break;
+      case EBUSY:
+        //Some thread forgot to unlock result
+        printf("%s:%i: Lock is still held.\n", __FILE__, __LINE__);
+        break;
+      case EINVAL:
+        //Invalid lock
+        printf("%s:%i: Lock is invalid.\n", __FILE__, __LINE__);
+        break;
+      default:
+        printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_destroy.\n", __FILE__, __LINE__, result);
+        break;
+    }
+    free(lock);
+  }
+  #endif
+}
+pthread_mutex_t* ENVIRONMENT::init_lock(pthread_mutex_t* lock) {
+  #ifdef THREADS
+  lock = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+  if (!lock)
+  {
+    printf("%s:%i: Could not allocate memory.\n", __FILE__, __LINE__);
+  }
+  int result = pthread_mutex_init(lock, NULL);
+  switch (result)
+  {
+    case 0:
+      //Succesfully initialized
+      break;
+    case EAGAIN:
+      //Not enough resources
+      printf("%s:%i: Not enough resources to create mutex.\n", __FILE__, __LINE__);
+      break;
+    case ENOMEM:
+      printf("%s:%i: Not enough memory to create mutex.\n", __FILE__, __LINE__);
+      break;
+    case EPERM:
+      printf("%s:%i: Not authorized.\n", __FILE__, __LINE__);
+      break;
+    case EBUSY:
+      printf("%s:%i: The mutex is already initialized.\n", __FILE__, __LINE__);
+      break;
+    case EINVAL:
+      printf("%s:%i: Invalid attribute.\n", __FILE__, __LINE__);
+      break;
+    default:
+      printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_init.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+  return lock;
+}
+void ENVIRONMENT::lock(pthread_mutex_t* lock)
+{
+  #ifdef THREADS
+  int result = pthread_mutex_lock(lock);
+  switch (result)
+  {
+    case 0:
+      //Got the lock.
+      break;
+    case EINVAL:
+      //Priority too high
+      printf("%s:%i: Either this thread's priority is higher than the mutex's priority, or the mutex is uninitialized.\n", __FILE__, __LINE__);
+      break;
+    case EAGAIN:
+      printf("%s:%i: Too many locks on the mutex.\n", __FILE__, __LINE__);
+      break;
+    case EDEADLK:
+      //We have the lock already
+      printf("%s:%i: Already have lock.\n", __FILE__, __LINE__);
+      break;
+    default:
+      //What error is this?
+      printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_lock.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+}
+void ENVIRONMENT::unlock(pthread_mutex_t* lock)
+{
+  #ifdef THREADS
+  int result = pthread_mutex_unlock(lock);
+  switch (result)
+  {
+    case 0:
+      //Released the lock
+      break;
+    case EPERM:
+      //Forgot to get a lock on the mutex
+      printf("%s:%i: Mutex isn't locked\n", __FILE__, __LINE__);
+      break;
+    case EINVAL:
+      //Uninitialized mutex
+      printf("%s:%i: waiting_sky_lock is uninitialized.\n", __FILE__, __LINE__);
+      break;
+    default:
+      //?
+      printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_unlock.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+}
+BITMAP* ENVIRONMENT::get_waiting_sky()
+{
+  lock(waiting_sky_lock);
+  BITMAP* w = waiting_sky;
+  unlock(waiting_sky_lock);
+  return w;
+}
+BITMAP* ENVIRONMENT::get_waiting_terrain()
+{
+  lock(waiting_terrain_lock);
+  BITMAP* w = waiting_terrain;
+  unlock(waiting_terrain_lock);
+  return w;
+}
 /*
 This function saves the environment settings to a text
 file. Each line has the format
