@@ -537,6 +537,8 @@ int Load_Weapons_Text(GLOBALDATA *global)
     sprintf(path_to_file, "%s/text/weapons_ru.txt", global->dataDir);
   else if (global->language == LANGUAGE_SPANISH)
     sprintf(path_to_file, "%s/text/weapons_ES.txt", global->dataDir);
+  else if (global->language == LANGUAGE_ITALIAN)
+    sprintf(path_to_file, "%s/text/weapons_it.txt", global->dataDir);
 
   // open file
   wfile = fopen(path_to_file, "r");
