@@ -117,7 +117,7 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
 
     my_tank = env->order[0];
     // init stuff complete. Get down to playing
-    while ( (! done) && (global->command != GLOBAL_COMMAND_QUIT) )
+    while ( (! done) && (global->get_command() != GLOBAL_COMMAND_QUIT) )
     {
         // see how long we have been skipping
         if (skippingComputerPlay)
@@ -192,7 +192,7 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
             else if (my_class == MISSILE_CLASS)
             {
               TANK *shooting_tank = NULL;
-              BEAM *defense_beam = NULL;
+              BEAM *defense_beam;
               int angle_to_fire;
 
               missile = (MISSILE *) my_object;
