@@ -27,6 +27,37 @@
 GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdates(NULL),allPlayers(NULL),
     players(NULL),currTank(NULL),saved_game_list(NULL)
 {
+  init_curland_lock();
+
+  command_lock = (pthread_rwlock_t*) malloc(sizeof(pthread_rwlock_t));
+  if (command_lock == NULL)
+  {
+    printf("%s:%i: Could not allocate memory for command_lock.\n", __FILE__, __LINE__);
+  }
+  int result = pthread_rwlock_init(command_lock, NULL);
+  switch (result)
+  {
+    case 0:
+       //Successfully initialized
+       break;
+    case EAGAIN:
+       //resource lack
+       printf("%s:%i: Not enough resources to initialize read-write lock.\n", __FILE__, __LINE__);
+       break;
+    case ENOMEM:
+       //out of memory
+       printf("%s:%i: Not enough memory to initialize read-write lock.\n", __FILE__, __LINE__);
+       break;
+    case EPERM:
+       //not authorized
+       printf("%s:%i: Not authorized.\n", __FILE__, __LINE__);
+       break;
+    default:
+       //If the switch ever gets to here, something very wrong happened and pthread_rwlock_init returned
+       //a random value
+       printf("%s:%i: Unknown error code (%i) returned by pthread_rwlock_init.\n", __FILE__, __LINE__, result);
+       break;
+  }
   tank_status = (char *)calloc(128, sizeof(char));
   if (!tank_status)
     {
@@ -122,6 +153,7 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
   numPlayers = 0;
   rounds = 5;
 
+  if (allPlayers) free(allPlayers);   // avoid potential leak
   allPlayers = (PLAYER**) calloc (1, sizeof (PLAYER*));
   if (!allPlayers)
     {
@@ -189,10 +221,247 @@ GLOBALDATA::~GLOBALDATA()
   if (retaliation) delete retaliation;
   if (kamikaze) delete kamikaze;
   if (suicide) delete suicide;
+  if (allPlayers) free(allPlayers);
+  if (command_lock)
+  {
+    int result = pthread_rwlock_destroy(command_lock);
+    switch (result)
+    {
+      case 0:
+         //Successfully destroyed
+         break;
+      case EBUSY:
+         //Some thread forgot to unlock the read-write lock
+         printf("%s:%i: Can't destroy because command_lock is still locked.\n", __FILE__, __LINE__);
+         break;
+      case EINVAL:
+         //Invalid lock
+         printf("%s:%i: The lock is invalid.\n", __FILE__, __LINE__);
+         break;
+      default:
+         //Something went wrong
+         printf("%s:%i: Unknown error code (%i) returned by pthread_rwlock_destroy.\n", __FILE__, __LINE__, result);
+         break;
+    }
+    free(command_lock);
+  }
+  destroy_curland_lock();
+}
+//Destroys curland_lock and frees it. If the lock is NULL or an error occurs, a diagnostic message will be printed.
+void GLOBALDATA::destroy_curland_lock() {
+  #ifdef THREADS
+  if (curland_lock != NULL)
+  {
+    int result = pthread_mutex_destroy(curland_lock);
+    switch (result)
+    {
+      case 0:
+        //Successfully destroyed
+        break;
+      case EBUSY:
+        //Some thread forgot to unlock result
+        printf("%s:%i: Lock is still held.\n", __FILE__, __LINE__);
+        break;
+      case EINVAL:
+        //Invalid lock
+        printf("%s:%i: Lock is invalid.\n", __FILE__, __LINE__);
+        break;
+      default:
+        printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_destroy.\n", __FILE__, __LINE__, result);
+        break;
+    }
+    free(curland_lock);
+  }
+  else
+  {
+    printf("%s:%i: Cannot destroy a null mutex.\n", __FILE__, __LINE__);
+  }
+  #endif
+}
+//init_curland_lock() allocates space for curland_lock and then calls pthread_mutex_init to initialize the lock. If the call fails, then this function will print diagnostic messages.
+void GLOBALDATA::init_curland_lock() {
+  #ifdef THREADS
+  curland_lock = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+  if (!curland_lock)
+  {
+    printf("%s:%i: Could not allocate memory for curland_lock.\n", __FILE__, __LINE__);
+  }
+  int result = pthread_mutex_init(curland_lock, NULL);
+  switch (result)
+  {
+    case 0:
+      //Succesfully initialized
+      break;
+    case EAGAIN:
+      //Not enough resources
+      printf("%s:%i: Not enough resources to create mutex.\n", __FILE__, __LINE__);
+      break;
+    case ENOMEM:
+      printf("%s:%i: Not enough memory to create mutex.\n", __FILE__, __LINE__);
+      break;
+    case EPERM:
+      printf("%s:%i: Not authorized.\n", __FILE__, __LINE__);
+      break;
+    case EBUSY:
+      printf("%s:%i: The mutex is already initialized.\n", __FILE__, __LINE__);
+      break;
+    case EINVAL:
+      printf("%s:%i: Invalid attribute.\n", __FILE__, __LINE__);
+      break;
+    default:
+      printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_init.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+}
+//lock_curland() locks curland and prints diagnostic messages if the lock operation fails.
+//Use get_curland() to read the value instead of directly using lock_curland()/unlock_curland() pairs.
+void GLOBALDATA::lock_curland()
+{
+  #ifdef THREADS
+  int result = pthread_mutex_lock(curland_lock);
+  switch (result)
+  {
+    case 0:
+      //Got the lock.
+      break;
+    case EINVAL:
+      //Priority too high
+      printf("%s:%i: Either this thread's priority is higher than the mutex's priority, or the mutex is uninitialized.\n", __FILE__, __LINE__);
+      break;
+    case EAGAIN:
+      printf("%s:%i: Too many locks on the mutex.\n", __FILE__, __LINE__);
+      break;
+    case EDEADLK:
+      //We have the lock already
+      printf("%s:%i: Already have lock.\n", __FILE__, __LINE__);
+      break;
+    default:
+      //What error is this?
+      printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_lock.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+}
+//unlock_curland() will unlock curland and print diagnostic messages if the unlock operation fails.
+void GLOBALDATA::unlock_curland()
+{
+  #ifdef THREADS
+  int result = pthread_mutex_unlock(curland_lock);
+  switch (result)
+  {
+    case 0:
+      //Released the lock
+      break;
+    case EPERM:
+      //Forgot to get a lock on the mutex
+      printf("%s:%i: Mutex isn't locked\n", __FILE__, __LINE__);
+      break;
+    case EINVAL:
+      //Uninitialized mutex
+      printf("%s:%i: waiting_sky_lock is uninitialized.\n", __FILE__, __LINE__);
+      break;
+    default:
+      //?
+      printf("%s:%i: Unknown error code (%i) returned by pthread_mutex_unlock.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+}
+//get_curland() locks curland, reads the value, unlocks curland, then returns the value. The value returned cannot be assigned to.
+//Use this only for reading the value of curland, not for writing.
+//For writing, use lock_curland()/unlock_curland().
+int GLOBALDATA::get_curland()
+{
+  lock_curland();
+  int c = curland;
+  unlock_curland();
+  return c;
 }
 
-
-
+//Locks global->command for writing. Unlock with GLOBALDATA::unlock_command().
+void GLOBALDATA::wr_lock_command()
+{
+  #ifdef THREADS
+  int result = pthread_rwlock_wrlock(command_lock);
+  switch (result)
+  {
+    case 0:
+      //Got the lock.
+      break;
+    case EINVAL:
+      //No lock has been created yet
+      printf("%s:%i: Read-write lock is uninitialized.\n", __FILE__, __LINE__);
+      break;
+    case EDEADLK:
+      //We have the lock already
+      printf("%s:%i: Can't lock for writing because the lock is already locked for either reading or writing.\n", __FILE__, __LINE__);
+      break;
+    default:
+      //What error is this?
+      printf("%s:%i: Unknown error code (%i) returned by pthread_rwlock_wrlock.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+}
+//Unlocks a read or a write lock. Do not try to use this function to unlock a lock acquired by calling get_command().
+void GLOBALDATA::unlock_command()
+{
+  #ifdef THREADS
+  int result = pthread_rwlock_unlock(command_lock);
+  switch (result)
+  {
+    case 0:
+      //Released the lock
+      break;
+    case EPERM:
+      //We have released all locks
+      printf("%s:%i: Can't unlock because no read or write lock is currently being held.\n", __FILE__, __LINE__);
+      break;
+    case EINVAL:
+      //Uninitialized read-write lock
+      printf("%s:%i: global->command_lock is uninitialized.\n", __FILE__, __LINE__);
+      break;
+    default:
+      //Something went wrong
+      printf("%s:%i: Unknown error code (%i) returned by pthread_rwlock_unlock.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+}
+//Locks global->command for reading, reads value, then unlocks the variable and returns the value.
+int GLOBALDATA::get_command()
+{
+  #ifdef THREADS
+  int result = pthread_rwlock_rdlock(command_lock);
+  switch (result)
+  {
+    case 0:
+      //Got the lock
+      break;
+    case EINVAL:
+      //No lock has been created.
+      printf("%s:%i: *global->command_lock is uninitialized.\n", __FILE__, __LINE__);
+      break;
+    case EAGAIN:
+      //Can't read since already trying to read
+      //Maybe locks are not being unlocked?
+      printf("%s:%i: Too many read locks already held.\n", __FILE__, __LINE__);
+      break;
+    case EDEADLK:
+      //Obtaining read locks while possessing a write lock is forbidden with read-write locks.
+      printf("%s:%i: Already own write lock; can't get read lock.\n", __FILE__, __LINE__);
+      break;
+    default:
+      //What error is this?
+      printf("%s:%i: Unknown error code (%i) returned by pthread_rwlock_rdlock.\n", __FILE__, __LINE__, result);
+      break;
+  }
+  #endif
+  int c = command;
+  unlock_command();
+  return c;
+}
 
 /*
 This function saves the global data to a text file. If all goes
