@@ -94,6 +94,10 @@ class GLOBALDATA
 
     PLAYER	**allPlayers;
     int	numPermanentPlayers;
+    pthread_rwlock_t* command_lock;
+    void wr_lock_command ();
+    void unlock_command ();
+    int get_command ();
     PLAYER	**players;
     int	numPlayers;
     int	numHumanPlayers;
@@ -108,6 +112,12 @@ class GLOBALDATA
     int	updateMenu;
 
     int	curland, cursky;
+    int get_curland();
+    void unlock_curland();
+    void lock_curland();
+    void destroy_curland_lock();
+    void init_curland_lock();
+    pthread_mutex_t* curland_lock;
 
     int	colourDepth;
     int	screenWidth, screenHeight;
