@@ -38,35 +38,35 @@ char *soundDriver[6] = { "Auto Detect", "OSS", "ESD", "ARTS", "ALSA", "JACK" };
 // portuege version
 char *onOffText_ptbr[2] = { "Desligado", "Ligado"};
 /*translate*/
-char *onOffRandomText_ptbr[3] = { "Desligado", "Ligado", "Random"};
-char *landSlideText_ptbr[5] = { "Nenhum", "Tanque Somente", "InstantÃ¢neo", "Gravidade", "Cartoon"};
-char *wallTypeText_ptbr[5] = { "ElÃ¡stico", "AÃ§o", "Mola", "Envoltório", "AleatÃ³rio"};
-char *mouseText_ptbr[2] = { "Personalizado", "PadrÃ£o"};
+char *onOffRandomText_ptbr[3] = { "Desligado", "Ligado", "Aleatório"};
+char *landSlideText_ptbr[5] = { "Nenhum", "Tanque Somente", "Instantâneo", "Gravidade", "Cartoon"};
+char *wallTypeText_ptbr[5] = { "Elástico", "Aço", "Mola", "Envoltório", "Aleatório"};
+char *mouseText_ptbr[2] = { "Personalizado", "Padrão"};
 char *meteorText_ptbr[4] = { "Desligado", "Fraco", "Forte", "Letal"};
-char *lightningText_ptbr[4] = { "Desligado", "Fraco", "EnergÃ©tico", "Violento"};
+char *lightningText_ptbr[4] = { "Desligado", "Fraco", "Energético", "Violento"};
 char *laserSatelliteText_ptbr[4] = { "Desligado", "Fraco", "Forte", "Super"};
 char *languageText_ptbr[8] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian", "Spanish", "Italian"};
 char *colourText_ptbr[2] = { "Regular", "Crispy"};
-char *landTypeText_ptbr[8] = { "aleatÃ³rio", "Canyons", "Montanhas", "Vales", "Colinas", "Morros", "Planos", "Nenhum" };
-char *turnTypeText_ptbr[4] = { "Melhores+", "Piores+", "AleatÃ³rio", "Simul" };
-char *skipTypeText_ptbr[2] = { "Desligado", "Humanos Mortos" };
+char *landTypeText_ptbr[8] = { "Aleatório", "Canyons", "Montanhas", "Vales", "Colinas", "Morros", "Planos", "Nenhum" };
+char *turnTypeText_ptbr[4] = { "Melhores+", "Piores+", "Aleatório", "Simular" };
+char *skipTypeText_ptbr[2] = { "Sim", "Não" };
 
 
 // french version
-char *onOffText_fr[2] = { "loin", "sur"};
+char *onOffText_fr[2] = { "Non", "Oui"};
 /*translate*/
-char *onOffRandomText_fr[3] = { "loin", "sur", "Random"};
+char *onOffRandomText_fr[3] = { "Non", "Oui", "Hasard"};
 char *landSlideText_fr[5] = { "Aucun", "Réservoir Seulement", "Instantané", "Gravité", "Dessin animé"};
-char *wallTypeText_fr[5] = { "Elastique", "Acier", "Mou", "Znveloppe", "Aléatoire"};
+char *wallTypeText_fr[5] = { "Elastique", "Acier", "Mou", "Enveloppe", "Aléatoire"};
 char *mouseText_fr[2] = { "Pesonnel", "Défaut"};
 char *meteorText_fr[4] = { "Off", "Light", "Heavy", "Lethal"};
 char *lightningText_fr[4] = { "Aucun", "Faible", "Energique", "Violent"};
 char *laserSatelliteText_fr[4] = { "Aucun", "Faible", "Fort", "Super"};
 char *languageText_fr[8] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian", "Spanish", "Italian"};
 char *colourText_fr[2] = { "Régulier", "Croustillant"};
-char *landTypeText_fr[8] = { "Aléatoire", "Canyons", "Mountagnes", "Vallées", "Collines", "Contreforts", "Plaines", "Aucun" };
-char *turnTypeText_fr[4] = { "Haut", "Bas", "Aléatoire", "Simulé" };
-char *skipTypeText_fr[2] = { "Aucun", "Mort des humains"};
+char *landTypeText_fr[8] = { "Aléatoire", "Canyons", "Montagnes", "Vallées", "Collines", "Contreforts", "Plaines", "Aucun" };
+char *turnTypeText_fr[4] = { "Haut", "Bas", "Aléatoire", "Similaire" };
+char *skipTypeText_fr[2] = { "Oui", "Non"};
 
 
 // german version
@@ -236,21 +236,21 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
       { "Gravidade", NULL, WHITE, &env->gravity, NULL, "%2.3f", .025, .325, 0.025, .075, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 80},
       { "Viscosidade", NULL, WHITE, &env->viscosity, NULL, "%2.2f", .25, 2.0, 0.25, 1.0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 60},
       { "Deslizamento de Terra", NULL, WHITE, &env->landSlideType, NULL, "%s", 0, 4, 1, 3, landSlideText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 40},
-      { "corrediça da terra atrasa", NULL, WHITE, &env->landSlideDelay, NULL, "%4.0f", 1, 5, 1, 3, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 20},
+      { "Corrediça da terra atrasa", NULL, WHITE, &env->landSlideDelay, NULL, "%4.0f", 1, 5, 1, 3, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 20},
       { "Tipo de Parede", NULL, WHITE, &env->wallType, NULL, "%s", 0, 4, 1, 1, wallTypeText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight},
-      { "modalidade encaixotada", NULL, WHITE, &env->dBoxedMode, NULL, "%s", 0, 2, 1, 0, onOffRandomText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 20},
-      { "morte violenta", NULL, WHITE, &global->violent_death, NULL, "%s", 0, 3, 1, 0, lightningText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 40},
-      { "tiro programado", NULL, WHITE, &global->max_fire_time, NULL, "%3.0f", 0, 180, 5, 0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 60}
+      { "Modalidade encaixotada", NULL, WHITE, &env->dBoxedMode, NULL, "%s", 0, 2, 1, 0, onOffRandomText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 20},
+      { "Morte violenta", NULL, WHITE, &global->violent_death, NULL, "%s", 0, 3, 1, 0, lightningText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 40},
+      { "Tiro programado", NULL, WHITE, &global->max_fire_time, NULL, "%3.0f", 0, 180, 5, 0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 60}
 
     };
-    MENUDESC physicsMenu = { "FÃ", 7, physicsOpts, TRUE, FALSE};
+    MENUDESC physicsMenu = { "Física", 7, physicsOpts, TRUE, FALSE};
 
     MENUENTRY weatherOpts[7] =
     {
       { "Chuvas de Meteoro", NULL, WHITE, &env->meteors, NULL, "%s", 0, 3, 1,
         0, meteorText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3,
         global->halfHeight - 68},
-      { "RelÃ¢mpagos", NULL, WHITE, &env->lightning, NULL, "%s", 0, 3, 1, 0,
+      { "Relâmpagos", NULL, WHITE, &env->lightning, NULL, "%s", 0, 3, 1, 0,
         lightningText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3,
         global->halfHeight - 48},
       { "Sujeira de queda", NULL, WHITE, &env->falling_dirt_balls, NULL, "%s", 0, 3, 1, 0, meteorText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -263,33 +263,33 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
       { "Velocidade Max do Vento", NULL, WHITE, (double*)&env->windstrength,
         NULL, "%2.0f", 0, 100, 5, 40, NULL, OPTION_DOUBLETYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 32 },
-      { "VariaÃ§Ã£o do Vento", NULL, WHITE, (double*)&env->windvariation,
+      { "Variação do Vento", NULL, WHITE, (double*)&env->windvariation,
         NULL, "%2.1f", 0, 100, 3, 10, NULL, OPTION_DOUBLETYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 52},
     };
-    MENUDESC weatherMenu = { "CondiÃ§Ãµes MeteorolÃ³gicas", 7, weatherOpts,
+    MENUDESC weatherMenu = { "Condições Meteorológicas", 7, weatherOpts,
                              TRUE, FALSE
                            };
 
     MENUENTRY soundOpts[3] =
     {
-      { "All Sound", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
-      { "Sound Driver", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
-      { "Music", NULL, WHITE, &global->play_music, NULL, "%s", 0, 1, 1, 0, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28}
+      { "Efeitos de Som", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
+      { "Sistema de Som", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
+      { "Música", NULL, WHITE, &global->play_music, NULL, "%s", 0, 1, 1, 0, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28}
     };
-   MENUDESC soundMenu = { "Sound", 3, soundOpts, TRUE, FALSE};
+   MENUDESC soundMenu = { "Som", 3, soundOpts, TRUE, FALSE};
 
 
     MENUENTRY graphicsOpts[12] =
     {
-      { "Full Screen", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
+      { "Tela Cheia", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
       { "Pontilhamento", NULL, WHITE, &global->ditherGradients, NULL, "%s",
         0, 1, 1, 1, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3,
         global->halfHeight - 88},
       { "Detalhes do Terreno", NULL, WHITE, &global->detailedLandscape, NULL,
         "%s", 0, 1, 1, 1, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE,
         global->halfWidth - 3, global->halfHeight - 68},
-      { "Detalhes do CÃ©u", NULL, WHITE, &global->detailedSky, NULL, "%s", 0,
+      { "Detalhes do Céu", NULL, WHITE, &global->detailedSky, NULL, "%s", 0,
         1, 1, 1, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3,
         global->halfHeight - 48},
       { "texto sombreado", NULL, WHITE, &env->dFadingText, NULL, "%s", 0, 1, 1, 1, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -302,14 +302,14 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
       { "Altura da Tela", NULL, WHITE, &global->temp_screenHeight,
         NULL, "%4.0f", 600, 1200, 200, 600, NULL, OPTION_DOUBLETYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 52},
-      { "Ponteiro do Mouse", NULL, WHITE, &global->os_mouse, NULL,
+      { "Ponteiro do Rato", NULL, WHITE, &global->os_mouse, NULL,
         "%s", 0, 1, 1, 1, mouseText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth
         - 1, global->halfHeight + 72},
-      { "velocidade do jogo", NULL, WHITE, &global->frames_per_second, NULL, "%3.0f", 30, 120, 5, 60, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
-      { "fundo feito sob encomenda", NULL, WHITE, &env->custom_background, NULL, "%s", 0, 1, 1, 0, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112}
+      { "Velocidade do jogo", NULL, WHITE, &global->frames_per_second, NULL, "%3.0f", 30, 120, 5, 60, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
+      { "Fundo personalizado", NULL, WHITE, &env->custom_background, NULL, "%s", 0, 1, 1, 0, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112}
 
     };
-    MENUDESC graphicsMenu = { "GrÃ¡ficos", 12, graphicsOpts, TRUE, FALSE};
+    MENUDESC graphicsMenu = { "Gráficos", 12, graphicsOpts, TRUE, FALSE};
 
     MENUENTRY financeOpts[9] =
     {
@@ -319,19 +319,19 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
       { "Taxa de Juros", NULL, WHITE, (double*)&global->interest, NULL,
         "%2.2f", 1.0, 1.5, 0.05, 1.25, NULL, OPTION_DOUBLETYPE, FALSE,
         global->halfWidth - 3, global->halfHeight - 48},
-      { "BÃ´nus por VitÃ³ria", NULL, WHITE,
+      { "Bônus por Vitória", NULL, WHITE,
         (double*)&global->scoreRoundWinBonus, NULL, "%2.0f", 0, 50000, 5000, 10000, NULL, OPTION_DOUBLETYPE,
         FALSE, global->halfWidth - 3, global->halfHeight - 8},
-      { "BÃ´nus por Estrago", NULL, WHITE, (double*)&global->scoreHitUnit,
+      { "Bônus por Estrago", NULL, WHITE, (double*)&global->scoreHitUnit,
         NULL, "%2.0f", 0, 500, 25, 75, NULL, OPTION_DOUBLETYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 12},
       { "Penalidade por Auto-Estrago", NULL, WHITE,
         (double*)&global->scoreSelfHit, NULL, "%2.0f", 0, 10000, 1000, 0, NULL, OPTION_DOUBLETYPE,
         FALSE, global->halfWidth - 3, global->halfHeight + 32},
-      { "BÃ´nus por Tanque DestruÃ", NULL, WHITE,
+      { "Bônus por Tanque Destruído", NULL, WHITE,
         (double*)&global->scoreUnitDestroyBonus, NULL, "%2.0f", 0, 20000, 2500, 5000, NULL,
         OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 52},
-      { "Penalidade por Auto-DestruiÃ§Ã£o", NULL, WHITE,
+      { "Penalidade por Auto-Destruição", NULL, WHITE,
         (double*)&global->scoreUnitSelfDestroy, NULL, "%2.0f", 0, 20000, 2500, 0, NULL,
         OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 72},
       { "Multiplicador de Item Vendido", NULL, WHITE,
@@ -344,9 +344,9 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
 
     MENUENTRY networkOpts[3] =
     {
-       {  "Check Updates", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
-       {  "Networking", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
-       {  "Listen Port", NULL, WHITE, (double*) &global->listen_port, NULL, "%5.0f", 10645, 64645, 1000, 25645, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 8}
+       {  "Procurar actualizações", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
+       {  "Activar Rede", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
+       {  "Número de Porta", NULL, WHITE, (double*) &global->listen_port, NULL, "%5.0f", 10645, 64645, 1000, 25645, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 8}
     };
     MENUDESC networkMenu = { "Network", 3, networkOpts, TRUE, FALSE};
 
@@ -360,35 +360,35 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
 
     MENUENTRY mainOpts[12] =
     {
-      { "FÃ", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0,
+      { "Física", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0,
         0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3,
         global->halfHeight - 88},
-      { "CondiÃ§Ãµes MeteorolÃ³gicas", NULL, WHITE, (double*)pWeatherMenu,
+      { "Condições Meteorológicas", NULL, WHITE, (double*)pWeatherMenu,
         NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth -
         3, global->halfHeight - 68},
-      { "GrÃ¡ficos", NULL, WHITE, (double*)pGraphicsMenu, NULL, NULL, 0, 0,
+      { "Gráficos", NULL, WHITE, (double*)pGraphicsMenu, NULL, NULL, 0, 0,
         0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3,
         global->halfHeight - 48},
-      { "Dinheiro", NULL, WHITE, (double*)pFinanceMenu, NULL, NULL, 0, 0, 0,
+      { "Finanças", NULL, WHITE, (double*)pFinanceMenu, NULL, NULL, 0, 0, 0,
         0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3,
         global->halfHeight - 28},
-       { "Network", NULL, WHITE, (double*)pnetworkMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 8},
-      { "Sound", NULL, WHITE, (double*) pSoundMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 12},
-      { "Arma NÃ TecnolÃ³gico", NULL, WHITE, (double*)&env->weapontechLevel, NULL,
+       { "Rede", NULL, WHITE, (double*)pnetworkMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 8},
+      { "Som", NULL, WHITE, (double*) pSoundMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 12},
+      { "Arma Nível Tecnológico", NULL, WHITE, (double*)&env->weapontechLevel, NULL,
         "%2.0f", 0, 5, 1, 5, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth -
         3, global->halfHeight + 32},
-      { "Artigo NÃ TecnolÃ³gico", NULL, WHITE, (double*) &env->itemtechLevel, NULL,
+      { "Artigo Nível Tecnológico", NULL, WHITE, (double*) &env->itemtechLevel, NULL,
         "%2.0f", 0, 5, 1, 5, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 52},
-      { "CenÃ¡rio", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7,
+      { "Cenário", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7,
         1, LANDTYPE_HILLS, landTypeText_ptbr, OPTION_SPECIALTYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 72},
       { "Ordem de Jogadas", NULL, WHITE, (double*)&global->turntype, NULL,
         "%s", 0, 3, 1, TURN_RANDOM, turnTypeText_ptbr, OPTION_SPECIALTYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 92},
-      { "Pular Jogo SÃ³ com RobÃ´s", NULL, WHITE, &global->skipComputerPlay,
+      { "Continuar o Jogo Só com Robôs", NULL, WHITE, &global->skipComputerPlay,
         NULL, "%s", 0, 2, 1, 1, skipTypeText_ptbr, OPTION_SPECIALTYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 112},
-      { "língua", NULL, WHITE, &global->language, NULL, "%s", 0, 7, 1, 0, languageText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
+      { "Língua", NULL, WHITE, &global->language, NULL, "%s", 0, 7, 1, 0, languageText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
 
     };
 // mainMenu = { "Menu Principal", 10, mainOpts, TRUE, FALSE};
@@ -411,9 +411,9 @@ if (global->language == LANGUAGE_FRENCH)
       { "Glissements de terrain", NULL, WHITE, &env->landSlideType, NULL, "%s", 0, 4, 1, 3, landSlideText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 40},
       { "Délai glissements de terrain", NULL, WHITE, &env->landSlideDelay, NULL, "%4.0f", 1, 5, 1, 3, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 20},
       { "Murs", NULL, WHITE, &env->wallType, NULL, "%s", 0, 4, 1, 1, wallTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight},
-      { "enfermé dans boîte", NULL, WHITE, &env->dBoxedMode, NULL, "%s", 0, 2, 1, 0, onOffRandomText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 20},
-      { "mort violente", NULL, WHITE, &global->violent_death, NULL, "%s", 0, 3, 1, 0, lightningText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 40},
-      { "projectile synchronisé", NULL, WHITE, &global->max_fire_time, NULL, "%3.0f", 0, 180, 5, 0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 60}
+      { "Enfermé dans boîte", NULL, WHITE, &env->dBoxedMode, NULL, "%s", 0, 2, 1, 0, onOffRandomText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 20},
+      { "Mort violente", NULL, WHITE, &global->violent_death, NULL, "%s", 0, 3, 1, 0, lightningText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 40},
+      { "Projectile synchronisé", NULL, WHITE, &global->max_fire_time, NULL, "%3.0f", 0, 180, 5, 0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 60}
 
     };
     MENUDESC physicsMenu = { "Physique", 7, physicsOpts, TRUE, FALSE};
@@ -432,9 +432,9 @@ if (global->language == LANGUAGE_FRENCH)
 
     MENUENTRY soundOpts[3] =
     {
-      { "All Sound", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
-      { "Sound Driver", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
-      { "Music", NULL, WHITE, &global->play_music, NULL, "%s", 0, 1, 1, 0, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28}
+      { "Effets Sonores", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
+      { "Système de Son", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
+      { "Musique", NULL, WHITE, &global->play_music, NULL, "%s", 0, 1, 1, 0, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28}
     };
    MENUDESC soundMenu = { "Sound", 3, soundOpts, TRUE, FALSE};
 
@@ -452,7 +452,7 @@ if (global->language == LANGUAGE_FRENCH)
       { "Hauteur d'écran", NULL, WHITE, &global->temp_screenHeight, NULL, "%4.0f", 600, 1200, 200, 600, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 52},
       { "Curseur de souris", NULL, WHITE, &global->os_mouse, NULL, "%s", 0, 1, 1, 1, mouseText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 1, global->halfHeight + 72},
       { "Vitesse du jeu", NULL, WHITE, &global->frames_per_second, NULL, "%3.0f", 30, 120, 5, 60, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
-      { "fond fait sur commande", NULL, WHITE, &env->custom_background, NULL, "%s", 0, 1, 1, 0, onOffText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112}
+      { "Fond fait sur commande", NULL, WHITE, &env->custom_background, NULL, "%s", 0, 1, 1, 0, onOffText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112}
     };
     MENUDESC graphicsMenu = { "Graphismes", 12, graphicsOpts, TRUE, FALSE};
 
@@ -469,7 +469,7 @@ if (global->language == LANGUAGE_FRENCH)
       { "Part d'equipes", NULL, WHITE, (double *) &global->divide_money, NULL, "%s", 0.0, 1.0, 1.0, 0.0, onOffText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112}
 
     };
-    MENUDESC financeMenu = { "Money", 9, financeOpts, TRUE, FALSE};
+    MENUDESC financeMenu = { "Finances", 9, financeOpts, TRUE, FALSE};
 
     MENUENTRY networkOpts[3] =
     {
@@ -491,16 +491,16 @@ if (global->language == LANGUAGE_FRENCH)
     MENUENTRY mainOpts[12] =
     {
       { "Physique", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
-      { "Métao", NULL, WHITE, (double*)pWeatherMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
+      { "Météo", NULL, WHITE, (double*)pWeatherMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Graphismes", NULL, WHITE, (double*)pGraphicsMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
       { "Finances", NULL, WHITE, (double*)pFinanceMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
-       { "Network", NULL, WHITE, (double*)pnetworkMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 8},
+      { "Réseau", NULL, WHITE, (double*)pnetworkMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 8},
       { "Sound", NULL, WHITE, (double*) pSoundMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 12},
       { "Niveau technique armes", NULL, WHITE, (double*)&env->weapontechLevel, NULL, "%2.0f", 0, 5, 1, 5, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 32},
       { "Niveau technique équipement", NULL, WHITE, (double *) &env->itemtechLevel, NULL, "%2.0f", 0, 5, 1, 5, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 52},
       { "Paysage", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7, 1, LANDTYPE_HILLS, landTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 72},
       { "Ordre de passage", NULL, WHITE, (double*)&global->turntype, NULL, "%s", 0, 3, 1, TURN_RANDOM, turnTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
-      { "Jeu IA seule", NULL, WHITE, &global->skipComputerPlay, NULL, "%s", 0, 1, 1, 1, skipTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112},
+      { "Continuer le Jeu Robots seuls", NULL, WHITE, &global->skipComputerPlay, NULL, "%s", 0, 1, 1, 1, skipTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112},
       { "Langue", NULL, WHITE, &global->language, NULL, "%s", 0, 7, 1, 0, languageText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
     };
 // mainMenu = { "Menu principal", 10, mainOpts, TRUE, FALSE};
