@@ -147,6 +147,7 @@ class PLAYER
     double team;
     int time_left_to_fire;
     bool skip_me;
+    int last_shield_used;
     #ifdef NETWORK
     int server_socket;
     char net_command[NET_COMMAND_SIZE];
@@ -193,6 +194,7 @@ class PLAYER
     int     Select_Random_Item();
     int    Reduce_Time_Clock();
     int    Buy_Something(int item_index);     // purchases the selected item
+    int    Reclaim_Shield();    // restore unused shield
 
     #ifdef NETWORK
     void Trim_Newline(char *line);   // sanitize input
