@@ -16,6 +16,7 @@ SATELLITE::~SATELLITE()
 void SATELLITE::Init()
 {
   x = _global->screenWidth / 2;
+  previous_x = x;
   y = 35;
   xv = -2;
 }
@@ -28,6 +29,7 @@ void SATELLITE::Move()
   else if (x > (_global->screenWidth - 10) )
     xv -= 1;
 
+  previous_x = x;
   x += xv;
 }
 
@@ -36,10 +38,11 @@ void SATELLITE::Move()
 void SATELLITE::Draw(BITMAP *dest)
 {
   drawing_mode(DRAW_MODE_SOLID, NULL, 0, 0);
-  draw_sprite(dest, (BITMAP *) _global->gfxData.M[SATELLITE_IMAGE].dat,
+  draw_sprite(dest, (BITMAP *) _global->misc[SATELLITE_IMAGE],
               x, y);
 
   _env->make_update(x - 20, y, 80, 60);
+  _env->make_update(previous_x, y, 80, 60);
 }
 
 
@@ -50,6 +53,9 @@ void SATELLITE::Shoot()
   BEAM *my_beam;
   int angle, laser_type;
 
+  if (_env->satellite == LASER_NONE)
+    return;
+
   if (_env->naturals_since_last_shot >= 3)
     return;
 
@@ -58,7 +64,8 @@ void SATELLITE::Shoot()
     {
       if (_env->satellite == LASER_WEAK) laser_type = SML_LAZER;
       else if (_env->satellite == LASER_STRONG) laser_type = MED_LAZER;
-      else laser_type = LRG_LAZER;
+      else if (_env->satellite == LASER_SUPER) laser_type = LRG_LAZER;
+      else return;
 
       angle = rand() % 30;
       my_beam = new BEAM(_global, _env, (xv < 0) ? x + 10: x + 40,
