@@ -404,17 +404,19 @@ void *Generate_Sky_In_Background(void *new_env)
    BITMAP *sky_in_progress = NULL;
 
    // do this constantly
-   while ( my_global->command != GLOBAL_COMMAND_QUIT )
+   while ( my_global->get_command() != GLOBAL_COMMAND_QUIT )
    {
       // create a bitmap in waiting, if none exists
-      if (! env->waiting_sky)
+      if (! env->get_waiting_sky())
       {
          sky_in_progress = create_bitmap( my_global->screenWidth, my_global->screenHeight - MENUHEIGHT);
          generate_sky (my_global, sky_in_progress, env->my_sky_gradients[my_global->cursky],
                    (my_global->ditherGradients ? GENSKY_DITHERGRAD : 0 ) |
                    (my_global->detailedSky ? GENSKY_DETAILED : 0 )  );
 
+         env->lock(env->waiting_sky_lock);
          env->waiting_sky = sky_in_progress;
+         env->unlock(env->waiting_sky_lock);
          sky_in_progress = NULL;
       }
 
