@@ -975,8 +975,8 @@ void TANK::activateCurrentSelection ()
   int z;
 
   // avoid firing weapons on exit in Windows
-  if ( (_global->command == GLOBAL_COMMAND_QUIT) ||
-       (_global->command == GLOBAL_COMMAND_MENU) )
+  if ( (_global->get_command() == GLOBAL_COMMAND_QUIT) ||
+       (_global->get_command() == GLOBAL_COMMAND_MENU) )
     return;
 
   // remove status from top bar at next redraw
